%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: MeanResidualAnalysisDelay.m
%
% Description: Implements the mean residual analysis 
%              model validation algorithm.
%
% Inputs: Output signals, residuals as well as a division 
%         into intervals of analysis.
%
% Outputs: Amplitude error curves as well as plots of the
%          amplitude signal energy distribution.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2003-06-05.
%               Delay estimation added in revision 3.0.
%
% Firm revision: revision 1.0, 2004-12-23.
%                revision 2.0, 2005-08-24 (no changes).
%                revision 3.0, 2017-01-27.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
% Input intervals. The intervals are supposed to be a row vector
%

while ~exist('intervals')
   'Input intervals for division into bins'
   keyboard
end

figure

%
% Compute residuals
%

residualError=y(:,1:N)-y_ms(:,1:N);

%
% Compute statistics
%

samplesPerInterval=0*intervals;
meanResidual=0*intervals;
numberOfIntervals=size(intervals,2)-1;
numberOfResiduals=size(intervals,1);
for i=1:numberOfResiduals
   for j=1:numberOfIntervals
      theseIntervals=find( (y(i,:)>=intervals(i,j)) & (y(i,:)<intervals(i,j+1)) );
      if ~isempty(theseIntervals)
         samplesPerInterval(i,j)=size(theseIntervals,2);
         meanResidual(i,j)=mean(residualError(i,theseIntervals));
      end
   end
end

%
% Plot
%

for i=1:numberOfResiduals
   subplot(2*numberOfResiduals,1,2*i-1)
   bar(intervals(i,:)',meanResidual(i,:)');
   xtext=['y(' num2str(i) ')'];
   xlabel(xtext);
   ylabel('mean residual');
   subplot(2*numberOfResiduals,1,2*i)   
   bar(intervals(i,:)',samplesPerInterval(i,:)');   
   xlabel(xtext);
   ylabel('number of samples');
end

%
% Force user to provide interval each time
%

clear intervals;

