%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: PlotPredictionErrorsDelay.m
%
% Description: Generates a plot of the prediction errors,
%              as saved during the identification.
%
% Inputs: Saved prediction errors.
%
% Outputs: Plot of the convergence of the prediction errors.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2003-06-05.
%               Tested with delay estimation in revision 3.0.
%
% Firm revision: revision 1.0, 2004-12-23.
%                revision 2.0, 2005-08-24 (no changes).
%                revision 3.0, 2017-02-27.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
% Prepare downsampling
%

SamplingInstances_DownSampled=SamplingInstances(downSampling:downSampling:N);


figure

%
% Get dimesion
%

numberOfPredictionErrors=size(perr_save,1);

%
% Plot
%

for i=1:numberOfPredictionErrors
   subplot(numberOfPredictionErrors,1,i)
   plot(SamplingInstances_DownSampled',perr_save(i,1:ceil(N/downSampling))');
   xlabel('time [s]')
   ytext=['prediction error (' num2str(i) ')'];
   ylabel(ytext);
end
