%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: SetupDataDelay.m
%
% Description: Script that contains all initialization required
%              to generate simulated data.
%
% Inputs: As written into m-file. 
%
% Outputs: Parameters required for signal generation.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2004-03-31.
%               Delay handling added 2017-01-25.
%
% Firm revision: revision 1.0, 2004-12-23.
%                revision 2.0, 2005-08-24 (no changes).
%                revision 3.0, 2017-01-25. 
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
% Set up parameters for data generation
%

% dimensions...

nu=1; % Input signal dimension
nx_0=1; % State dimension
ny=1; % Output dimension, normally 1

% Input signal related...Type may be selected among:
%
% InputType=[
%    'PRBS       ';
%    'Gaussian   ';
%    'UniformPRBS';
%    'SineWave   ';
%    'Custom     '];
   
InputType=[
   'UniformPRBS'];
uAmplitude=[
   1.0];
uMean=[
   0];
uFrequency=[
   0.2];
ClockPeriod=[
   30];% Clock period vector in terms of sampling time

% System disturbance related...Type may be selected among:
%
% DisturbanceTypeSystem=[
%   'WGN     ';
%   'SineWave';
%   'Custom  '];

DisturbanceTypeSystem=[
   'WGN     '];
wSigma=[
   0.0]; % Gaussian system noise standard deviation (discrete time)
wMean=[
   0];
wSineAmplitude=[
   0];
wSineFrequency=[
   0];

% Measurement disturbance related... Type may be selected among:
%
% DisturbanceTypeMeasuremet=[
%   'WGN     ';
%   'SineWave';
%   'Custom  '];

DisturbanceTypeMeasurement=[
   'WGN     '];
eSigma=0.1; % Gaussian measurement noise standard deviation (discrete time)
eMean=[
   0];
eSineAmplitude=[
   0];
eSineFrequency=[
   0];

% sampling time, data length and delay

Ts=0.1; % Sampling time in seconds
N=3000; % Number of data points
SamplingInstances=(Ts:Ts:N*Ts);
Td=1.22; % Delay in seconds

% ODE related...

x0=[0.5]'; % Initial values
