%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: SetupRPEMDelay.m
%
% Description: Script that sets up all parameters required to run
%              the RPEM, with added delay estimation
%
% Inputs: As written into script. 
%
% Outputs: Parameters required by the RPEM.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2004-03-31.
%               Delay identification added 2017-01-25.
%
% Firm revision: revision 1.0, 2004-12-23.
%                revision 2.0, 2005-08-24 (no changes).
%                revision 3.0. 2017-01-25.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
%  State initial value
%

nx=1;
x_m_0=[0.5]';
nu_m=nu;
u_m_0=u(:,1);
dudt_m_0=dudt(:,1);

%
% Remaining initial values
%

muFactor=300; % To stabilize Gamma and to reduce the gain
if exist('theta_0_new')
   muFactor=1000;
end
mu_0=10;
mu0=0.9995;
y_m_0=0;
initialNoiseVariance=0.1; % Initial value for the prediction error variance
scaleFactorR=10; % the size of the initial diagonal approximation of the Hessian
scaleFactorRDelay=1; % the size of the initial diagonal approximation of the Hessian

%
% Parameters
%

stabilityLimit=0.975; % The linearized pole radius used for stability checking and projection
downSampling=1; % The downsampling factor used when data from the run is saved
scalingTs=1; % The scaling factor with which the sampling period is multiplied during identification
Td_min=0.0; % The minimum delay allowed during identification
Td_max=2.00; % The maximum delay allowed during identification
nd=ceil((Td_max-Td_min)/Ts)+1; % The number of samples covering the allowed delay span
