%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: SimulateModelOutputDelay.m
%
% Description: Simulates the model output, using parameters
%              obtained at the end of the run. Also computes
%              the corresponding residuals. Delay added.
%
% Inputs: Input signals, estimated parameters as well as the 
%         system output signals. 
%
% Outputs: Simulated output signals and corresponding residuals.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2003-06-05.
%               Delay estimation added in revision 3.
%
% Firm revision: revision 1.0, 2004-12-23.
%				 revision 2.0, 2005-08-24 (no changes).
%                revision 3.0, 2017-01-27.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
% Initialization
%

% Main variables

x_ms=zeros(nx,N+1);
y_ms=zeros(ny,N+1);
x_ms(:,1)=x_m_0;
percentReady=0;

% Delayed variables

u_ms_d=[];
y_ms_d=[];
x_ms_d=[];
for i=1:nd
    u_ms_d=[u_ms_d u_m_0];
    y_ms_d=[y_ms_d y_m_0];
    x_ms_d=[x_ms_d x_m_0];
end;

% Integrate with an Euler method

for t=SamplingInstances(1,1):Ts:SamplingInstances(1,N-1)
   if round(t*100/N/Ts)>percentReady
      percentReady=round(t*100/N/Ts)
   end
   k=round(t/Ts); % Sampling index into matrices

   % Calculate delayed u
   
   for i=1:nd
       if (t-i>=0)
          u_ms_d(:,i)=u(:,k-i+1);
       else
          u_ms_d(:,i)=u(:,1);
       end
   end
   if (intDelay>0)
      uNext_ms=(1-alpha)*u_ms_d(:,intDelay)+alpha*u_ms_d(:,intDelay+1);
   else
      uNext_ms=(1-alpha)*u(:,k+1)+alpha*u_ms_d(:,intDelay+1);
   end
   
   % Calculate delayed x_ms
   
   for i=nd:-1:2
      x_ms_d(:,i)=x_ms_d(:,i-1);
   end
   x_ms_d(:,1)=x_ms_d(:,1)+Ts*f_m(x_ms_d(:,1),u_ms_d(:,1),rescaledTheta(2:dimTheta,1),allIndices);

   x_ms=(1-alpha)*x_ms_d(:,intDelay+1)+alpha*x_ms_d(:,intDelay+2);
   
   % Calculate output
   
   y_ms(:,k)=h_m(x_ms,uNext_ms);
end

y_ms=y_ms(:,1:N);